export function removeReadOnly(schema) {
    const newSchema = removeReadOrWriteOnly(schema, 'readOnly');
    return {
        ...appendToRefs(newSchema, "_request"),
        'x-location': schema['x-location'],
        'x-name': schema['x-name'],
        'x-schema-type': schema['x-schema-type'],
        'x-service-name': schema['x-service-name'],
        'x-standalone': schema['x-standalone'],
    };
}
export function removeWriteOnly(schema) {
    const newSchema = removeReadOrWriteOnly(schema, 'writeOnly');
    return {
        ...appendToRefs(newSchema, "_response"),
        'x-location': schema['x-location'],
        'x-name': schema['x-name'],
        'x-schema-type': schema['x-schema-type'],
        'x-service-name': schema['x-service-name'],
        'x-standalone': schema['x-standalone'],
    };
}
function appendToRefs(schema, appendString) {
    const stringifiedSchema = JSON.stringify(schema);
    const appendedStringifiedSchema = stringifiedSchema.replace(/"(\$ref":".*?)"/g, `"$1${appendString}"`);
    return JSON.parse(appendedStringifiedSchema);
}
function removeReadOrWriteOnly(schema, readOrWriteOnly) {
    const newSchema = JSON.parse(JSON.stringify(schema));
    switch (newSchema.type) {
        case 'array':
            return handleArray(newSchema, readOrWriteOnly);
        case 'boolean':
            return newSchema;
        case 'integer':
            return newSchema;
        case 'null':
            return newSchema;
        case 'number':
            return newSchema;
        case 'object':
            return handleObject(newSchema, readOrWriteOnly);
        case 'string':
            return newSchema;
        default:
            return handleUndefined(newSchema, readOrWriteOnly);
    }
}
function handleArray(schema, readOrWriteOnly) {
    if (schema.type !== 'array')
        throw new Error("Schema is not of type 'array'");
    schema.items = removeReadOrWriteOnly(schema.items, readOrWriteOnly);
    return schema;
}
function handleObject(schema, readOrWriteOnly) {
    if (schema.type !== 'object')
        throw new Error("Schema is not of type 'object'");
    for (const propertyName in schema.properties) {
        if (schema.properties[propertyName][readOrWriteOnly]) {
            delete schema.properties[propertyName];
            if (schema.required?.includes(propertyName)) {
                schema.required = schema.required.filter((name) => name !== propertyName);
            }
        }
    }
    schema.allOf = schema.allOf?.map((allOfSchema) => removeReadOrWriteOnly(allOfSchema, readOrWriteOnly));
    schema.anyOf = schema.anyOf?.map((anyOfSchema) => removeReadOrWriteOnly(anyOfSchema, readOrWriteOnly));
    schema.oneOf = schema.oneOf?.map((oneOfSchema) => removeReadOrWriteOnly(oneOfSchema, readOrWriteOnly));
    return schema;
}
function handleUndefined(schema, readOrWriteOnly) {
    if (schema.type)
        throw new Error('Schema type is not undefined');
    schema.allOf = schema.allOf?.map((allOfSchema) => removeReadOrWriteOnly(allOfSchema, readOrWriteOnly));
    schema.anyOf = schema.anyOf?.map((anyOfSchema) => removeReadOrWriteOnly(anyOfSchema, readOrWriteOnly));
    schema.oneOf = schema.oneOf?.map((oneOfSchema) => removeReadOrWriteOnly(oneOfSchema, readOrWriteOnly));
    return schema;
}
//# sourceMappingURL=removeReadWriteOnly.js.map